<?php

namespace EventPortal\Domain\Component;

use EventPortal\Domain\Util\Parameters;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Support\Arr;

class Button extends Component
{
    const TYPE = 'Button';

    /** @var InertiaMethod */
    public $method;

    /** @var string */
    public $route;

    /** @var string */
    public $variant = 'primary';

    /** @var array */
    public $routeParams = [];

    public function method(InertiaMethod $method): self
    {
        $this->method = $method->getValue();

        return $this;
    }

    /**
     * @param string|array $parameters
     */
    public function route(string $route, $parameters = []): self
    {
        $this->route = $route;

        if ($parameters) {
            $this->routeParams = Parameters::make(Arr::wrap($parameters))->asPlain()->asArray();
        }

        return $this;
    }

    public function variant(string $variant): self
    {
        $this->variant = $variant;

        return $this;
    }

    /**
     * Represents the button in array format.
     */
    public function toArray(): array
    {
        $data = [
            'component' => self::TYPE,
            'label' => $this->label,
            'variant' => $this->variant,
        ];

        if ($this->method) {
            $data['method'] = $this->method;
        }

        if ($this->route) {
            $data['route'] = $this->route;
        }

        if ($this->routeParams) {
            $data['routeParams'] = $this->routeParams;
        }

        if ($this->classes) {
            $data['classes'] = $this->classes;
        }

        return $data;
    }
}
