<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Table\GroupedActions;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Builder;

Table::make('event-delegate.index')
    ->tapQuery(function (Builder $query) {
        return $query->joinRelationship('user');
    })
    ->addAvailableColumns(function () {
        return [
            Text::make('First name'),
            Text::make('Last name'),
            Text::make('Email'),
            Select::make('Status')->options([
                Option::make('Invited'),
                Option::make('Registered'),
            ]),
        ];
    })
    ->addDefaultColumns(function () {
        return [
            Text::make('First name'),
            Text::make('Last name'),
            Text::make('Email'),
            Select::make('Status')->options([
                Option::make('Invited'),
                Option::make('Registered'),
            ]),
        ];
    })
    ->addRowAction(function (Event $event, Delegate $delegate) {
        return GroupedActions::make('Manage delegate')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.delegate.show', [
                        'event' => $event->id,
                        'delegate' => $delegate->id,
                    ]),
            ]);
    });

Table::make('event-delegate.add')
    ->joinRelation('user')
    ->addGlobalAction(function (Event $event) {
        return GroupedActions::make('Manage delegates')
            ->actions([
                Button::make('Add')
                    ->method(InertiaMethod::POST())
                    ->route('admin.event.delegate.add', [
                        'event' => $event->id,
                    ]),
            ]);
    });
